@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2017 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2019 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -12,6 +12,34 @@
 
 
 
+
+
+getarg <- function(a) {
+
+
+
+  b <- unlist(strsplit(a, "(", fixed = TRUE))
+
+  if (length(b) == 2) {  # Usual case
+    d <- unlist(strsplit(b[2], ")", fixed = TRUE))
+    d[1]
+  } else if (length(b) == 1) {  # identitylink
+    b
+  } else if (length(b) == 3) {  # nbcanlink
+    d <- unlist(strsplit(b[2], ",", fixed = TRUE))
+    d[1]
+  } else {
+    a
+  }
+}  # getarg
+
+
+
+
+
+
+
+
 subsetcol <-
 Select <-
   function(
@@ -65,7 +93,7 @@ Select <-
     exclude.index <- NULL
     for (ii in seq_along(exclude)) {
       exclude.index <- c(exclude.index,
-                         (seq_along(col.names))[exclude[ii] == col.names])
+                  (seq_along(col.names))[exclude[ii] == col.names])
     }
     exclude.index <- unique(sort(exclude.index))
     index <- setdiff(index, exclude.index)
@@ -93,7 +121,7 @@ Select <-
                           if (ltcn.positive)
                             paste(temp.col.names, collapse = " + ") else
                             "",
-                          ifelse(ltcn.positive && length(rhs ), " + ", ""),
+                      ifelse(ltcn.positive && length(rhs ), " + ", ""),
                           ifelse(length(rhs ), rhs, ""),
                           ifelse(length(rhs2), paste(" +", rhs2), ""),
                           ifelse(length(rhs3), paste(" +", rhs3), ""))
@@ -119,7 +147,7 @@ Select <-
       }
     }
   }
-}
+}  # subsetcol, Select
 
 
 
@@ -203,7 +231,7 @@ subsetc <-
 
   myvec <- objvals[ans == vov]  # Could be a vector
   if (ret.objfun) c(Value = ans, ObjFun = myvec[1]) else ans
-}
+}  # grid.search
 
 
 
@@ -234,7 +262,7 @@ subsetc <-
   c(Value1 = allmat1[ind5, "vov1"],
     Value2 = allmat1[ind5, "vov2"],
     ObjFun = if (ret.objfun) objvals[ind5] else NULL)
-}
+}  # grid.search2
 
 
 
@@ -268,7 +296,9 @@ subsetc <-
     Value2 = allmat1[ind5, "vov2"],
     Value3 = allmat1[ind5, "vov3"],
     ObjFun = if (ret.objfun) objvals[ind5] else NULL)
-}
+}  # grid.search3
+
+
 
 
 
@@ -308,12 +338,7 @@ subsetc <-
     Value3 = allmat1[ind5, "vov3"],
     Value4 = allmat1[ind5, "vov4"],
     ObjFun = if (ret.objfun) objvals[ind5] else NULL)
-}
-
-
-
-
-
+}  # grid.search4
 
 
 
@@ -332,7 +357,7 @@ subsetc <-
   }
 
   ans <- vector("list", M+1)
-  names(ans) <- c(paste("eta", 1:M, sep = ""), "ncolX.vlm")
+  names(ans) <- c(param.names("eta", M), "ncolX.vlm")
 
   temp2 <- matrix(unlist(constraints), nrow = M)
   for (kk in 1:M) {
@@ -350,7 +375,7 @@ subsetc <-
   ans[[M+1]] <- ncol(temp2)
 
   ans
-}
+}  # genind
 
 
 
@@ -454,7 +479,9 @@ subsetc <-
   }
 
   constraints
-}
+}  # cm.VGAM
+
+
 
 
 
@@ -494,7 +521,9 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
   temp <- temp[, -nointercept, drop = FALSE]
   constraints[["(Intercept)"]] <- temp
   constraints
-}
+}  # cm.nointercept.VGAM
+
+
 
 
 
@@ -503,6 +532,15 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
                           predictors.names, M1 = 1) {
 
 
+
+  if (is.character(predictors.names)) {
+    for (ii in 1:length(predictors.names))
+      predictors.names[ii] <- getarg(predictors.names[ii])
+  }
+
+
+
+
   dotzero <- zero  # Transition
 
   if (length(dotzero) == 1 && (dotzero == "" || is.na(dotzero)))
@@ -520,7 +558,8 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
       if (length(which.ones)) {
         which.numeric.all <- c(which.numeric.all, which.ones)
       } else {
-        warning("some values of argument 'zero' are unmatched. Ignoring them")
+        warning("some values of argument 'zero' are unmatched. ",
+                "Ignoring them")
       }
     }  # for ii
     which.numeric <- unique(sort(which.numeric.all))
@@ -603,15 +642,17 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
     }  # for ii
 
   constraints
-}
+}  # cm.zero.VGAM
+
+
+
 
 
 
  process.constraints <-
   function(constraints, x, M,
            by.col = TRUE, specialCM = NULL,
-           Check.cm.rank = TRUE  # 20140626
-          ) {
+           Check.cm.rank = TRUE) {
 
 
 
@@ -648,30 +689,30 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
       if (!is.null  (constraints[[ii]]) &&
           !is.matrix(constraints[[ii]]))
         stop("'constraints[[", ii, "]]' is not a matrix")
-    }
+    }  # for ii
 
   if (is.null(names(constraints)))
     names(constraints) <- rep_len(nasgn, lenconstraints)
 
-  temp <- vector("list", length(nasgn))
-  names(temp) <- nasgn
+  tmp3 <- vector("list", length(nasgn))
+  names(tmp3) <- nasgn
   for (ii in seq_along(nasgn))
-    temp[[nasgn[ii]]] <-
+    tmp3[[nasgn[ii]]] <-
       if (is.null(constraints[[nasgn[ii]]])) diag(M) else
              eval(constraints[[nasgn[ii]]])
 
   for (ii in seq_along(asgn)) {
-    if (!is.matrix(temp[[ii]])) {
-      stop("not a constraint matrix")
+    if (!is.matrix(tmp3[[ii]])) {
+      stop("component ", ii, "is not a constraint matrix")
     }
-    if (ncol(temp[[ii]]) > M)
+    if (ncol(tmp3[[ii]]) > M)
       stop("constraint matrix has too many columns")
   }
 
   if (!by.col)
-    return(temp)
+    return(tmp3)
 
-  constraints <- temp
+  constraints <- tmp3
   Hlist <- vector("list", ncol(x))
   for (ii in seq_along(asgn)) {
     cols <- asgn[[ii]]
@@ -688,7 +729,7 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
       Hlist[[jay]] <- cm
     }
   }
-  names(Hlist) <- dimnames(x)[[2]]
+  names(Hlist) <- colnames(x)  # dimnames(x)[[2]]
 
 
 
@@ -708,7 +749,7 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
   }
 
   Hlist
-}
+}  # process.constraints
 
 
 
@@ -744,7 +785,7 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
     if (trivc[ii] == 0) next
   }
   trivc
-}
+}  # trivial.constraints
 
 
 
@@ -792,12 +833,7 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
   }
 
   constraints
-}
-
-
-
-
-
+}  # add.constraints
 
 
 
@@ -840,7 +876,7 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
             (i1 == kay & i2 == jay)
     (seq_along(i2))[both]
   }
-}
+}  # iam
 
 
 
@@ -855,7 +891,7 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
   if (hbw > M || hbw < 1)
     stop("range error in argument 'hbw'")
   hbw * (2 * M - hbw +1) / 2
-}
+}  # dimm
 
 
 
@@ -892,7 +928,7 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
   alpn <- NULL
   dimnames(fred$ans) <- list(alpn, alpn, dimnames(m)[[1]])
   fred$a
-}
+}  # m2a
 
 
 
@@ -926,8 +962,7 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
     attr(fred$m, "hbw") <- hbw
   if (length(lpn <- dimnames(a)[[1]]) != 0)
     attr(fred$m, "predictors.names") <- lpn
-  fred$m
-}
+}  # a2m
 
 
 
@@ -955,15 +990,16 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
   if (length.arg > length(ans))
     stop("argument 'length.arg' too big")
   rep_len(ans, length.arg)
-}
+}  # vindex
 
 
 
 
 
 
- wweights <- function(object, matrix.arg = TRUE, deriv.arg = FALSE,
-                      ignore.slot = FALSE, checkwz = TRUE) {
+ wweights <-
+  function(object, matrix.arg = TRUE, deriv.arg = FALSE,
+           ignore.slot = FALSE, checkwz = TRUE) {
 
 
 
@@ -988,7 +1024,7 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
   if (any(slotNames(object) == "predictors"))
     eta <- object@predictors
   mt <- terms(object)  # object@terms$terms; 20030811
-  Hlist <- constraints <- object@constraints
+  Hlist <- object@constraints
   new.coeffs <- object@coefficients
   if (any(slotNames(object) == "iter"))
     iter <- object@iter
@@ -1008,6 +1044,8 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
     y <- depvar(object)
 
 
+  X.vlm.save <- model.matrixvlm(object, type = "vlm")
+
 
   if (length(object@misc$form2)) {
     Xm2 <- object@Xm2
@@ -1039,6 +1077,9 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
       assign(ii, object@misc[[ii]])
     }
 
+
+
+
   if (any(slotNames(object) == "family")) {
     expr <- object@family@deriv
     deriv.mu <- eval(expr)
@@ -1055,7 +1096,7 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
   } else {
     NULL
   }
-}
+}  # wweights
 
 
 
@@ -1072,7 +1113,8 @@ cm.nointercept.VGAM <- function(constraints, x, nointercept, M) {
     names(ans) <- dimnames(temp)[[1]]
     ans
   }
-}
+}  # pweights
+
 
 
 
@@ -1118,7 +1160,7 @@ procVec <- function(vec, yn, Default) {
   }
 
   answer
-}
+}  # procVec
 
 
 
@@ -1131,9 +1173,10 @@ if (FALSE) {
 
 
 
- weightsvglm <- function(object, type = c("prior", "working"),
-                        matrix.arg = TRUE, ignore.slot = FALSE,
-                        deriv.arg = FALSE, ...) {
+ weightsvglm <-
+  function(object, type = c("prior", "working"),
+           matrix.arg = TRUE, ignore.slot = FALSE,
+           deriv.arg = FALSE, ...) {
   weightsvlm(object, type = type, matrix.arg = matrix.arg,
               ignore.slot = ignore.slot,
               deriv.arg = deriv.arg, ...)
@@ -1141,9 +1184,10 @@ if (FALSE) {
 
 
 
- weightsvlm <- function(object, type = c("prior", "working"),
-                       matrix.arg = TRUE, ignore.slot = FALSE,
-                       deriv.arg = FALSE, ...) {
+ weightsvlm <-
+  function(object, type = c("prior", "working"),
+           matrix.arg = TRUE, ignore.slot = FALSE,
+           deriv.arg = FALSE, ...) {
   if (mode(type) != "character" && mode(type) != "name")
     type <- as.character(substitute(type))
   type <- match.arg(type, c("prior", "working"))[1]
@@ -1158,7 +1202,7 @@ if (FALSE) {
     ans <- pweights(object)
     if (matrix.arg) as.matrix(ans) else c(ans)
   }
-}
+}  # weightsvlm
 
 
 
@@ -1198,7 +1242,7 @@ qnupdate <- function(w, wzold, dderiv, deta, M, keeppd = TRUE,
   }
   Bs <- mux22(t(wzold), deta, M = M,
               upper = FALSE, as.matrix = TRUE)  # n x M
-  sBs <- c( (deta * Bs) %*% rep_len(1, M) )  # should have positive values
+  sBs <- c( (deta * Bs) %*% rep_len(1, M) )  # should have positive vals
   sy <- c( (dderiv * deta) %*% rep_len(1, M) )
   wznew <- wzold
   index <- iam(NA, NA, M = M, both = TRUE)
@@ -1221,7 +1265,10 @@ qnupdate <- function(w, wzold, dderiv, deta, M, keeppd = TRUE,
     flush.console()
   }
   wznew
-}
+}  # qnupdate
+
+
+
 
 
 
@@ -1248,7 +1295,10 @@ mbesselI0 <- function(x, deriv.arg = 0) {
     if (deriv.arg>=1) ans[,2] <- besselI(x, nu = 1)
     if (deriv.arg>=2) ans[,3] <- ans[,1] - ans[,2] / x
     ans
-}
+}  # mbesselI0
+
+
+
 
 
 
@@ -1267,7 +1317,7 @@ VGAM.matrix.norm <- function(A, power = 2, suppressWarning = FALSE) {
   } else {
     stop("argument 'power' not recognized")
   }
-}
+}  # VGAM.matrix.norm
 
 
 
@@ -1284,7 +1334,9 @@ rmfromVGAMenv <- function(varnames, prefix = "") {
       rm(list = ii, envir = VGAMenv)
     }
   }
-}
+}  # rmfromVGAMenv
+
+
 
 
 
@@ -1299,7 +1351,11 @@ existsinVGAMenv <- function(varnames, prefix = "") {
     ans <- c(ans, is.there)
   }
   ans
-}
+}  # existsinVGAMenv
+
+
+
+
 
 
 assign2VGAMenv <- function(varnames, mylist, prefix = "") {
@@ -1308,7 +1364,7 @@ assign2VGAMenv <- function(varnames, mylist, prefix = "") {
     assign(evarnames[ii], mylist[[(varnames[ii])]],
            envir = VGAMenv)
   }
-}
+}  # assign2VGAMenv
 
 
 
@@ -1324,6 +1380,9 @@ getfromVGAMenv <- function(varname, prefix = "") {
 
 
 
+
+
+
 lerch <- function(x, s, v, tolerance = 1.0e-10, iter = 100) {
   if (!is.Numeric(x) || !is.Numeric(s) || !is.Numeric(v))
     stop("bad input in 'x', 's', and/or 'v'")
@@ -1350,7 +1409,7 @@ lerch <- function(x, s, v, tolerance = 1.0e-10, iter = 100) {
            as.integer(iter))
 
   ifelse(ans$err == 0 & xok , ans$result, NA)
-}
+}  # lerch
 
 
 
@@ -1379,11 +1438,12 @@ negzero.expression.VGAM <- expression({
   which.numeric.all <- NULL
   for (ii in seq_along(dotzero)) {
     which.ones <-
-        grep(dotzero[ii], predictors.names, fixed = TRUE)
+      grep(dotzero[ii], predictors.names, fixed = TRUE)
     if (length(which.ones)) {
       which.numeric.all <- c(which.numeric.all, which.ones)
     } else {
-      warning("some values of argument 'zero' are unmatched. Ignoring them")
+      warning("some values of argument 'zero' are unmatched. ",
+              "Ignoring them")
     }
   }
   which.numeric <- unique(sort(which.numeric.all))
@@ -1423,8 +1483,10 @@ negzero.expression.VGAM <- expression({
                NULL else
                unique(sort(c(zneg.index, zpos.index)))
 
-  constraints <- cm.zero.VGAM(constraints, x = x, z.Index, M = M)
-})
+  constraints <- cm.zero.VGAM(constraints, x = x, z.Index, M = M,
+                              predictors.names = predictors.names,
+                              M1 = M1)
+})  # negzero.expression.VGAM
 
 
 
@@ -1453,7 +1515,9 @@ is.empty.list <- function(mylist) {
   } else {
     c(matrix(1:(.M), nrow = M1, byrow = TRUE))
   }
-}
+}  # interleave.VGAM
+
+
 
 
 
@@ -1470,14 +1534,15 @@ interleave.cmat <- function(cmat1, cmat2) {
       return(cbind(cmat1[, 1], cmat2, cmat1[, -1]))
     } else
     if (ncol1 != ncol2) {
-      warning("this function is confused. Returning cbind(cmat1, cmat2)")
+      warning("this function is confused. ",
+              "Returning cbind(cmat1, cmat2)")
       return(cbind(cmat1[, 1], cmat2, cmat1[, -1]))
     } else {  # ncol1 == ncol2 and both are > 1.
       kronecker(cmat1, cbind(1, 0)) +
       kronecker(cmat2, cbind(0, 1))
     }
   }
-}
+}  # interleave.cmat
 
 
 
@@ -1535,8 +1600,7 @@ w.wz.merge <- function(w, wz, n, M, ndepy,
   }  # ii
 
   w.rep * wz
-}
-
+}  # w.wz.merge
 
 
 
@@ -1608,7 +1672,7 @@ w.y.check <- function(w, y,
   if (out.wy && ncol(w) < Ncol.max.w) {
     nblanks <- sum(cn.w == "")
     if (nblanks > 0)
-      cn.w[cn.w == ""] <- paste(prefix.w, 1:nblanks, sep = "")
+      cn.w[cn.w == ""] <- param.names(prefix.w, nblanks)
     if (length(cn.w) < Ncol.max.w)
       cn.w <- c(cn.w, paste(prefix.w, (length(cn.w)+1):Ncol.max.w,
                             sep = ""))
@@ -1617,7 +1681,7 @@ w.y.check <- function(w, y,
   if (out.wy && ncol(y) < Ncol.max.y) {
     nblanks <- sum(cn.y == "")
     if (nblanks > 0)
-      cn.y[cn.y == ""] <- paste(prefix.y, 1:nblanks, sep = "")
+      cn.y[cn.y == ""] <- param.names(prefix.y, nblanks)
     if (length(cn.y) < Ncol.max.y)
       cn.y <- c(cn.y, paste(prefix.y, (length(cn.y)+1):Ncol.max.y,
                             sep = ""))
@@ -1626,7 +1690,8 @@ w.y.check <- function(w, y,
 
   list(w = if (out.wy) w else NULL,
        y = if (out.wy) y else NULL)
-}
+}  # w.y.check
+
 
 
 
@@ -1669,7 +1734,47 @@ arwz2wz <- function(arwz, M = 1, M1 = 1, rm.trailing.cols = TRUE,
   }
 
   wz
-}
+}  # arwz2wz
+
+
+
+
+
+
+wz.merge <- function(wz1, wz2, M1, M2, rm.trailing.cols = TRUE) {
+
+
+  if (!is.matrix(wz1))
+    wz1 <- cbind(wz1)
+  if (!is.matrix(wz2))
+    wz2 <- cbind(wz2)
+  M <- M1 + M2
+  wz <- matrix(0.0, nrow(wz1), M*(M+1)/2)
+
+  for (ilocal in 1:M1)
+    for (jlocal in ilocal:M1)
+      if (iam(ilocal, jlocal, M = M1) <= ncol(wz1)) {
+         wz[, iam(ilocal, jlocal, M = M)] <-
+        wz1[, iam(ilocal, jlocal, M = M1)]
+      }
+
+  for (ilocal in 1:M2)
+    for (jlocal in ilocal:M2)
+      if (iam(ilocal, jlocal, M = M2) <= ncol(wz2)) {
+         wz[, iam(M1+ilocal, M1+jlocal, M = M)] <-
+        wz2[, iam(   ilocal,    jlocal, M = M2)]
+      }
+
+  if (rm.trailing.cols) {
+    colind <- ncol(wz)
+    while (all(wz[, colind] == 0))
+      colind <- colind - 1
+    if (colind < ncol(wz))
+      wz <- wz[, 1:colind, drop = FALSE]
+  }
+
+  wz
+}  # wz.merge
 
 
 
@@ -1677,34 +1782,39 @@ arwz2wz <- function(arwz, M = 1, M1 = 1, rm.trailing.cols = TRUE,
 
 
 
+param.names <- function(string, S = 1, skip1 = FALSE, sep = "") {
+  if (skip1) {
+    if (S == 1) string else paste(string, 1:S, sep = sep)
+  } else {
+    paste(string, 1:S, sep = sep)
+  }
+}  # param.names
+
 
-param.names <- function(string, S) {
-  if (S == 1) string else paste(string, 1:S, sep = "")
-}
 
 
 
 
 
 vweighted.mean.default <- function (x, w, ..., na.rm = FALSE) {
-  temp5 <- w.y.check(w = w, y = x, ncol.w.max = Inf, ncol.y.max = Inf,
-                     out.wy = TRUE,
-                     colsyperw = 1,
-                     maximize = TRUE,
-                     Is.integer.y = FALSE,
-                     Is.positive.y = FALSE,
-                     Is.nonnegative.y = FALSE,
-                     prefix.w = "PriorWeight",
-                     prefix.y = "Response")
+  tmp5 <- w.y.check(w = w, y = x, ncol.w.max = Inf, ncol.y.max = Inf,
+                    out.wy = TRUE,
+                    colsyperw = 1,
+                    maximize = TRUE,
+                    Is.integer.y = FALSE,
+                    Is.positive.y = FALSE,
+                    Is.nonnegative.y = FALSE,
+                    prefix.w = "PriorWeight",
+                    prefix.y = "Response")
 
-  x <- temp5$y
-  w <- temp5$w
+  x <- tmp5$y
+  w <- tmp5$w
 
   ans <- numeric(ncol(w))
   for (ii in 1:ncol(w))
     ans[ii] <- weighted.mean(x[, ii], w = w[, ii], ..., na.rm = na.rm)
   ans
-}
+}  # vweighted.mean.default
 
 
 
@@ -1747,12 +1857,20 @@ setMethod("familyname", "vlm",
 
 
 
-bisection.basic <- function(f, a, b, tol = 1e-9, nmax = 500, ...) {
+
+bisection.basic <-
+  function(f, a, b, tol = 1e-9, nmax = NULL, ...) {
 
 
 
-  if (!all(sign(f(a, ...)) * sign(f(b, ...)) <= 0))
-    stop("roots do not exist between 'a' and 'b'")
+  if (is.null(nmax)) {
+    nmax <- round(log2(max(b - a)) - log2(min(tol))) + 4
+  }
+  signtest <- (sign(f(a, ...)) * sign(f(b, ...)) <= 0)
+
+  if (!all(signtest))
+    warning("roots do not exist between 'a' and 'b'. ",
+            "Some answers may be misleading.")
 
   N <- 1
   while (N <= nmax) {
@@ -1769,7 +1887,7 @@ bisection.basic <- function(f, a, b, tol = 1e-9, nmax = 500, ...) {
 
   warning("did not coverge. Returning final root")
   mid
-}
+}  # bisection.basic
 
 
 
@@ -1780,6 +1898,80 @@ retain.col <- function(mat, coln
   if (is.matrix(mat))  # && exclude
     mat[, -coln] <- 0
   mat
-}
+}  # retain.col
+
+
+
+
+
+
+which.etas <-
+  function(object, kay = 1) {
+
+  cmat <- constraints(object, matrix = TRUE)
+  if (ncol(cmat) < kay)
+    stop("value of argument 'kay' is too large")
+  which(cmat[, kay] != 0)
+}  # which.etas
+
+
+
+
+
+which.xij <-
+  function(object, ...) {
+
+  cmat <- constraints(object, matrix = TRUE)
+  ans <- rep(FALSE, NCOL(cmat))
+  names(ans) <- colnames(cmat)
+  xij <- object@control$xij
+  if (!is.null(xij)) {
+    for (ii in 1:length(xij)) {
+      responsevar <- all.vars(xij[[ii]])[1]
+      ans[responsevar] <- TRUE  # Assumes NCOL(cmat) == 1
+    }
+  }
+  ans
+}  # which.xij
+
+
+
+
+
+
+
+attr.assign.x.vglm <- function(object) {
+  x.lm.vglm <- NULL
+  x.lm.vglm <- try(model.matrix(formula(object),
+                                data = get(object@misc$dataname)), TRUE)
+  if (!length(x.lm.vglm))
+    x.lm.vglm <- try(model.matrix(formula(object)), TRUE)
+  if (!length(x.lm.vglm))
+    stop("cannot create the 'lm'-type model matrix from formula(object)")
+
+
+  attr.x.lm.vglm <- attr(x.lm.vglm, "assign")
+
+  clist <- constraints(object, type = "term")  # type = "lm" is default
+  ncols.cm <- unlist(lapply(clist, function(cm) ncol(cm)))
+
+  icounter <- 1
+  attr.x.vglm <- NULL
+  for (ii in min(attr.x.lm.vglm):max(attr.x.lm.vglm)) {
+    attr.x.vglm <- c(attr.x.vglm,
+                     rep(ii, sum(attr.x.lm.vglm == ii) *
+                             ncols.cm[icounter]))
+    icounter <- icounter + 1
+  }
+
+  attr.x.vglm
+}  # attr.assign.x.vglm
+
+
+
+
+
+
+
 
 
