@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2017 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2019 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -16,7 +16,10 @@
 
 
 
- cens.poisson <- function(link = "loge", imu = NULL) {
+ cens.poisson <-
+  function(link = "loglink", imu = NULL,
+           biglambda = 10,
+           smallno = 1e-10) {
 
   link <- as.list(substitute(link))
   earg <- link2list(link)
@@ -27,6 +30,18 @@
   blurb = c("Censored Poisson distribution\n\n",
             "Link:     ", namesof("mu", link, earg = earg), "\n",
             "Variance: mu"),
+  infos = eval(substitute(function(...) {
+    list(M1 = 1,
+         expected = FALSE,
+         multipleResponses = FALSE,
+         parameters.names = c("mu"),
+         link = .link ,
+         biglambda = .biglambda ,
+         smallno = .smallno )
+  }, list( .link = link,
+           .biglambda = biglambda,
+           .smallno = smallno ))),
+
   initialize = eval(substitute(expression({
     if (anyNA(y))
       stop("NAs are not allowed in the response")
@@ -41,35 +56,38 @@
     centype <- attr(y, "type")
 
     if (centype == "right") {
-        temp <- y[, 2]
-        extra$uncensored <- ifelse(temp == 1, TRUE, FALSE)
-        extra$rightcensored <- ifelse(temp == 0, TRUE, FALSE)
-        extra$leftcensored <- rep_len(FALSE, n)
-        extra$interval <- rep_len(FALSE, n)
-        init.mu <- pmax(y[, 1], 1/8)
+      temp <- y[, 2]
+      extra$uncensored <- ifelse(temp == 1, TRUE, FALSE)
+      extra$rightcensored <- ifelse(temp == 0, TRUE, FALSE)
+      extra$leftcensored <- rep_len(FALSE, n)
+      extra$interval <- rep_len(FALSE, n)
+      init.mu <- pmax(y[, 1], 1/8)
     } else
     if (centype == "left") {
-        temp <- y[, 2]
-        extra$uncensored <- ifelse(temp == 1, TRUE, FALSE)
-        extra$rightcensored <- rep_len(FALSE, n)
-        extra$leftcensored <- ifelse(temp == 0, TRUE, FALSE)
-        extra$interval <- rep_len(FALSE, n)
-        init.mu <- pmax(y[, 1], 1/8)
+      temp <- y[, 2]
+      extra$uncensored <- ifelse(temp == 1, TRUE, FALSE)
+      extra$rightcensored <- rep_len(FALSE, n)
+      extra$leftcensored <- ifelse(temp == 0, TRUE, FALSE)
+      extra$interval <- rep_len(FALSE, n)
+      init.mu <- pmax(y[, 1], 1/8)
     } else
     if (centype == "interval" ||
         centype == "interval2") {
-        temp <- y[, 3]
-        extra$uncensored <- ifelse(temp == 1, TRUE, FALSE)
-        extra$rightcensored <- ifelse(temp == 0, TRUE, FALSE)
-        extra$leftcensored <- ifelse(temp == 2, TRUE, FALSE)
-        extra$intervalcensored <- ifelse(temp == 3, TRUE, FALSE)
-        init.mu <- pmax((y[, 1] + y[, 2])/2, 1/8)  # for intervalcensored
-        if (any(extra$uncensored))
-        init.mu[extra$uncensored] <- pmax(y[extra$uncensored, 1], 1/8)
-        if (any(extra$rightcensored))
-     init.mu[extra$rightcensored] <- pmax(y[extra$rightcensored, 1], 1/8)
-        if (any(extra$leftcensored))
-       init.mu[extra$leftcensored] <- pmax(y[extra$leftcensored, 1], 1/8)
+      temp <- y[, 3]
+      extra$uncensored <- ifelse(temp == 1, TRUE, FALSE)
+      extra$rightcensored <- ifelse(temp == 0, TRUE, FALSE)
+      extra$leftcensored <- ifelse(temp == 2, TRUE, FALSE)
+      extra$intervalcensored <- ifelse(temp == 3, TRUE, FALSE)
+      init.mu <- pmax((y[, 1] + y[, 2])/2, 1/8)  # intervalcensored
+      if (any(extra$uncensored))
+        init.mu[extra$uncensored] <-
+          pmax(y[extra$uncensored, 1], 1/8)
+      if (any(extra$rightcensored))
+        init.mu[extra$rightcensored] <-
+          pmax(y[extra$rightcensored, 1], 1/8)
+      if (any(extra$leftcensored))
+        init.mu[extra$leftcensored] <-
+          pmax(y[extra$leftcensored, 1], 1/8)
     } else
     if (centype == "counting") {
       stop("type == 'counting' not compatible with cens.poisson()")
@@ -84,23 +102,18 @@
         namesof("mu", .link, earg = .earg, short = TRUE)
 
       if (!length(etastart))
-        etastart <- theta2eta(init.mu, link = .link, earg = .earg)
+        etastart <- theta2eta(init.mu, link = .link , earg = .earg )
   }), list( .link = link, .earg = earg, .imu = imu))),
   linkinv = eval(substitute(function(eta, extra = NULL) {
-    mu <- eta2theta(eta, link = .link, earg = .earg)
-    mu
+    mu <- eta2theta(eta, link = .link , earg = .earg )
+    as.vector(mu)
   }, list( .link = link, .earg = earg ))),
   last = eval(substitute(expression({
-    misc$expected <- FALSE
-
-    misc$link <-    c("mu" = .link)
-
-    misc$earg <- list("mu" = .earg)
-
-    misc$multipleResponses <- FALSE
+    misc$link <-    c("mu" = .link )
+    misc$earg <- list("mu" = .earg )
   }), list( .link = link, .earg = earg ))),
   linkfun = eval(substitute(function(mu, extra = NULL) {
-    theta2eta(mu, link = .link, earg = .earg)
+    theta2eta(mu, link = .link , earg = .earg )
   }, list( .link = link, .earg = earg ))),
   loglikelihood = function(mu, y, w, residuals = FALSE, eta,
                            extra = NULL) {
@@ -129,53 +142,96 @@
     cenL <- extra$leftcensored
     cenU <- extra$rightcensored
     cenI <- extra$intervalcensored
-      lambda <- eta2theta(eta, link = .link , earg = .earg )
+    lambda <- eta2theta(eta, link = .link , earg = .earg )
 
-      dl.dlambda <- (y[, 1] - lambda)/lambda   # uncensored
+    dl.dlambda <-  y[, 1] / lambda - 1  # uncensored
 
-      yllim <- yulim <- y[, 1]   # uncensored
+    yllim <- yulim <- y[, 1]  # uncensored
 
-      if (any(cenU)) {
-        yllim[cenU] <- y[cenU, 1]
-        densm1 <- dpois(yllim-1, lambda)
-        queue <- ppois(yllim-1, lambda, lower.tail = FALSE)
-        dl.dlambda[cenU] <- densm1[cenU] / queue[cenU]
+    if (any(cenU)) {
+      yllim[cenU] <- y[cenU, 1]
+      densm1 <- dpois(yllim-1, lambda)
+      queue <- ppois(yllim-1, lambda, lower.tail = FALSE)
+      dl.dlambda[cenU] <- densm1[cenU] / queue[cenU]
+      if (any(fix.up <- (is.na(dl.dlambda) |
+                         queue < .smallno ) &
+                         cenU &
+                         lambda > .biglambda )) {
+        zedd <- (yllim[fix.up] - 1) / sqrt(lambda[fix.up]) -
+                sqrt(lambda[fix.up])
+        dl.dlambda[fix.up] <-
+          mills.ratio(-zedd) / sqrt(lambda[fix.up])
       }
-      if (any(cenL)) {
-          yulim[cenL] <- y[cenL, 1] - 1
-          densm0 <- dpois(yulim, lambda)
-          Queue <- ppois(yulim, lambda)    # Left tail probability
-          dl.dlambda[cenL] <- -densm0[cenL] / Queue[cenL]
-      }
-      if (any(cenI)) {
-          yllim[cenI] <- y[cenI, 1] + 1
-          yulim[cenI] <- y[cenI, 2]
-          Queue1 <- ppois(yllim-1, lambda)
-          Queue2 <- ppois(yulim, lambda)
-          densm02 <- dpois(yulim, lambda)
-          densm12 <- dpois(yllim-1, lambda)
-          dl.dlambda[cenI] <-
-              (-densm02[cenI]+densm12[cenI]) / (Queue2[cenI]-Queue1[cenI])
+    }
+    if (any(cenL)) {
+      yulim[cenL] <- y[cenL, 1] - 1
+      densm0 <- dpois(yulim, lambda)
+      Queue <- ppois(yulim, lambda)  # Left tail probability
+      dl.dlambda[cenL] <- -densm0[cenL] / Queue[cenL]
+      if (any(fix.up <- (is.na(dl.dlambda) |
+                         Queue < .smallno ) &
+                         cenL &
+                         lambda > .biglambda )) {
+        dl.dlambda[fix.up] <-
+          -mills.ratio(yulim[fix.up] / sqrt(lambda[fix.up]) -
+                        sqrt(lambda[fix.up])) / sqrt(lambda[fix.up])
       }
+    }
+    if (any(cenI)) {
+      yllim[cenI] <- y[cenI, 1] + 1
+      yulim[cenI] <- y[cenI, 2]
+      Queue1 <- ppois(yllim-1, lambda)
+      Queue2 <- ppois(yulim  , lambda)
+      densm02 <- dpois(yulim  , lambda)
+      densm12 <- dpois(yllim-1, lambda)
+      dl.dlambda[cenI] <-
+        (-densm02[cenI]+densm12[cenI]) / (Queue2[cenI]-Queue1[cenI])
+    }
 
-      dlambda.deta <- dtheta.deta(theta=lambda, link =  .link, earg = .earg)
+    dlambda.deta <- dtheta.deta(theta = lambda,
+                                link =  .link , earg = .earg )
 
-    c(w) * dl.dlambda * dlambda.deta
-  }), list( .link = link, .earg = earg ))),
+    der1 <- c(w) * dl.dlambda * dlambda.deta
+    der1
+  }), list( .link = link, .earg = earg,
+            .biglambda = biglambda ,
+            .smallno = smallno ))),
   weight = eval(substitute(expression({
     d2lambda.deta2 <- d2theta.deta2(theta = lambda,
-                                    link = .link, earg = .earg )
-    d2l.dlambda2 <- 1 / lambda # uncensored; Fisher scoring
+                                    link = .link , earg = .earg )
+    d2l.dlambda2 <- 1 / lambda  # uncensored; Fisher scoring
 
     if (any(cenU)) {
       densm2 <- dpois(yllim-2, lambda)
       d2l.dlambda2[cenU] <- (dl.dlambda[cenU])^2 -
-          (densm2[cenU]-densm1[cenU])/queue[cenU]
+          (densm2[cenU] - densm1[cenU]) / queue[cenU]
+      if (any(fix.up <- is.na(d2l.dlambda2) | fix.up)) {
+ warning("incorrect as one of the queue uses yulim, not yulim-1")
+
+        zeddm1 <- (yllim[fix.up] - 1) /  sqrt(lambda[fix.up]) -
+                      sqrt(lambda[fix.up])
+        zeddm2 <- (yllim[fix.up] - 2) /  sqrt(lambda[fix.up]) -
+                      sqrt(lambda[fix.up])
+
+        d2l.dlambda2[fix.up] <- (dl.dlambda[fix.up])^2 -
+        (mills.ratio(-zeddm2) -
+         mills.ratio(-zeddm1)) / sqrt(lambda[fix.up])
+      }
     }
+
     if (any(cenL)) {
       densm1 <- dpois(yulim-1, lambda)
       d2l.dlambda2[cenL] <- (dl.dlambda[cenL])^2 -
-          (densm0[cenL]-densm1[cenL])/Queue[cenL]
+          (densm0[cenL] - densm1[cenL]) / Queue[cenL]
+
+      if (any(fix.up <- is.na(d2l.dlambda2) | fix.up)) {
+        d2l.dlambda2[fix.up] <- (dl.dlambda[fix.up])^2 -
+        (mills.ratio(yulim[fix.up] / sqrt(lambda[fix.up]) -
+                      sqrt(lambda[fix.up])) -
+         mills.ratio((yulim[fix.up] - 1) / sqrt(lambda[fix.up]) -
+                      sqrt(lambda[fix.up]))) / sqrt(lambda[fix.up])
+      }
+
     }
     if (any(cenI)) {
       densm03 <- dpois(yulim-1, lambda)
@@ -186,15 +242,19 @@
     }
     wz <-  c(w) * ((dlambda.deta^2) * d2l.dlambda2)
     wz
-  }), list( .link = link, .earg = earg ))))
-}
+  }), list( .link = link, .earg = earg,
+            .biglambda = biglambda ,
+            .smallno = smallno ))))
+}  # cens.poisson
+
+
 
 
 
 
 if (FALSE)
  cens.exponential <-
- ecens.exponential <- function(link = "loge", location = 0) {
+ ecens.exponential <- function(link = "loglink", location = 0) {
   if (!is.Numeric(location, length.arg = 1))
     stop("bad input for 'location'")
 
@@ -225,8 +285,8 @@ if (FALSE)
     } else if (type == "interval") {
       temp <- y[, 3]
       mu <- ifelse(temp == 3,
-                   y[, 2] + (abs(y[, 2] - extra$location) < 0.001) / 8,
-                   y[, 1] + (abs(y[, 1] - extra$location) < 0.001) / 8)
+            y[, 2] + (abs(y[, 2] - extra$location) < 0.001) / 8,
+            y[, 1] + (abs(y[, 1] - extra$location) < 0.001) / 8)
     }
     if (!length(etastart))
       etastart <- theta2eta(1/(mu-extra$location), .link , .earg )
@@ -304,7 +364,7 @@ if (FALSE)
     cenI <- extra$interval
     dl.drate <- 1/rate - (y[, 1]-extra$location)  # uncensored
     tmp200 <- exp(-rate*(y[, 1]-extra$location))
-    tmp200b <- exp(-rate*(y[, 2]-extra$location))  # for interval censored
+    tmp200b <- exp(-rate*(y[, 2]-extra$location))  # interval censored
     if (any(cenL))
       dl.drate[cenL] <- (y[cenL, 1]-extra$location) *
                         tmp200[cenL] / (1 - tmp200[cenL])
@@ -312,8 +372,8 @@ if (FALSE)
       dl.drate[cenU] <- -(y[cenU, 1]-extra$location)
     if (any(cenI))
       dl.drate[cenI] <- ((y[cenI, 2] - extra$location) *
-                        tmp200b[cenI] - (y[cenI, 1] - extra$location) *
-                        tmp200[cenI]) / (-tmp200b[cenI] + tmp200[cenI])
+                    tmp200b[cenI] - (y[cenI, 1] - extra$location) *
+                    tmp200[cenI]) / (-tmp200b[cenI] + tmp200[cenI])
 
     drate.deta <- dtheta.deta(rate, .link , .earg )
 
@@ -333,19 +393,19 @@ if (FALSE)
     d2l.drate2[ind50] <- (Lowpt[ind50]-extra$location)^2 *
                         tmp300[ind50] / (1-tmp300[ind50])
     d2l.drate2 <- d2l.drate2 + (exp(-rate*(Lowpt-extra$location)) -
-                               exp(-rate*(Upppt-extra$location))) * A123
+                  exp(-rate*(Upppt-extra$location))) * A123
 
     wz <- c(w) * (drate.deta^2) * d2l.drate2
     wz
     }), list( .link = link ))))
-}
+}  # cens.exponential
 
 
 
 
 
  cennormal <-
- cens.normal <- function(lmu = "identitylink", lsd = "loge",
+ cens.normal <- function(lmu = "identitylink", lsd = "loglink",
                          imethod = 1, zero = "sd") {
 
 
@@ -442,7 +502,8 @@ if (FALSE)
 
     Lower <- ifelse(cenL, y, -Inf)
     Upper <- ifelse(cenU, y,  Inf)
-    ell1 <- -log(sdv[cen0]) - 0.5 * ((y[cen0] - mum[cen0])/sdv[cen0])^2
+    ell1 <- -log(sdv[cen0]) -
+            0.5 * ((y[cen0] - mum[cen0])/sdv[cen0])^2
     ell2 <- log1p(-pnorm((mum[cenL] - Lower[cenL]) / sdv[cenL]))
     ell3 <- log1p(-pnorm(( Upper[cenU] -  mum[cenU]) / sdv[cenU]))
     if (residuals) stop("loglikelihood residuals not ",
@@ -532,7 +593,8 @@ if (FALSE)
     tmp8 <- (1-PhiU)*temp21U
     wzcenU11 <- phiU * (phiU - tmp8) / temp31U
     tmp9 <- (1-PhiU) * (2 - temp21U^2)
-    wzcenU22 <- mumU * phiU * (tmp9 + mumU * phiU / sdv) / (sdv * temp31U)
+    wzcenU22 <- mumU * phiU * (tmp9 +
+                mumU * phiU / sdv) / (sdv * temp31U)
     wzcenU12 <- -phiU * ((1-PhiU)*(temp21U^2 - 1) -
                  temp21U*phiU) / temp31U
     wzcenU11[!is.finite(wzcenU11)] <- 0  # Needed when Upper==Inf
@@ -546,12 +608,14 @@ if (FALSE)
     wz[, iam(1, 2, M)] <- wz[, iam(1, 2, M)] * dmu.deta * dsd.deta
     c(w) * wz
   }), list( .lmu = lmu, .lsd = lsd ))))
-}
+}  # cens.normal
 
 
 
 
- cens.rayleigh <- function(lscale = "loge",
+
+
+ cens.rayleigh <- function(lscale = "loglink",
                            oim  = TRUE) {
 
   lscale <- as.list(substitute(lscale))
@@ -638,7 +702,8 @@ if (FALSE)
 
     if ( .oim ) {
       d2l.dScale2 <- 3 * (y[cenU])^2 / (Scale[cenU])^4
-      d2Scale.deta2 <- d2theta.deta2(Scale[cenU], .lscale , earg = .escale )
+      d2Scale.deta2 <- d2theta.deta2(Scale[cenU], .lscale ,
+                                     earg = .escale )
       wz[cenU] <- (dScale.deta[cenU])^2 * d2l.dScale2 -
                    dl.dScale[cenU] * d2Scale.deta2
     } else {
@@ -649,7 +714,7 @@ if (FALSE)
     c(w) * wz
   }), list( .lscale = lscale, .escale = escale,
             .oim = oim ))))
-}
+}  # cens.rayleigh
 
 
 
@@ -661,7 +726,7 @@ if (FALSE)
 
 
  weibull.mean <-
-  function(lmean = "loge", lshape = "loge",
+  function(lmean = "loglink", lshape = "loglink",
            imean = NULL,   ishape = NULL,
            probs.y = c(0.2, 0.5, 0.8),
            imethod = 1, zero = "shape") {
@@ -756,15 +821,16 @@ if (FALSE)
            "don't use SurvS4()")
 
 
-    mynames1 <- param.names("mean" , ncoly)
-    mynames2 <- param.names("shape", ncoly)
+    mynames1 <- param.names("mean" , ncoly, skip1 = TRUE)
+    mynames2 <- param.names("shape", ncoly, skip1 = TRUE)
     predictors.names <-
         c(namesof(mynames1, .lmeann , earg = .emeann , tag = FALSE),
           namesof(mynames2, .lshape , earg = .eshape , tag = FALSE))
     predictors.names <- predictors.names[interleave.VGAM(M, M1 = M1)]
 
 
-    Meann.init <- matrix(if (length( .imeann )) .imeann else 0.5 * colMeans(y),
+    Meann.init <- matrix(if (length( .imeann ))
+                         .imeann else 0.5 * colMeans(y),
                          n, ncoly, byrow = TRUE) + 0.5 * y
     Shape.init <- matrix(if (length( .ishape )) .ishape else 0 + NA,
                          n, ncoly, byrow = TRUE)
@@ -817,8 +883,8 @@ if (FALSE)
       warning("MLE regularity conditions are violated",
               "(shape == 2) at the final iteration: ",
               "MLEs exist and are normal and asymptotically ",
-              "efficient but with a slower convergence rate than when ",
-              "shape > 2")
+              "efficient but with a slower convergence rate than ",
+              "when shape > 2")
     }
 
 
@@ -915,7 +981,7 @@ if (FALSE)
 
     wz
   }), list( .eshape = eshape ))))
-}
+}  # weibull.mean
 
 
 
@@ -923,7 +989,7 @@ if (FALSE)
 
 
  weibullR <-
-  function(lscale = "loge", lshape = "loge",
+  function(lscale = "loglink", lshape = "loglink",
            iscale = NULL,   ishape = NULL,
            lss = TRUE,
            nrfs = 1,
@@ -1032,15 +1098,15 @@ if (FALSE)
 
 
     if ( .lss ) {
-      mynames1 <- param.names("scale", ncoly)
-      mynames2 <- param.names("shape", ncoly)
+      mynames1 <- param.names("scale", ncoly, skip1 = TRUE)
+      mynames2 <- param.names("shape", ncoly, skip1 = TRUE)
       predictors.names <-
           c(namesof(mynames1, .lscale , earg = .escale , tag = FALSE),
             namesof(mynames2, .lshape , earg = .eshape , tag = FALSE))
 
     } else {
-      mynames1 <- param.names("shape", ncoly)
-      mynames2 <- param.names("scale", ncoly)
+      mynames1 <- param.names("shape", ncoly, skip1 = TRUE)
+      mynames2 <- param.names("scale", ncoly, skip1 = TRUE)
       predictors.names <-
           c(namesof(mynames1, .lshape , earg = .eshape , tag = FALSE),
             namesof(mynames2, .lscale , earg = .escale , tag = FALSE))
@@ -1195,6 +1261,7 @@ if (FALSE)
 
 
 
+
     ned2l.dscale <- (Shape / Scale)^2
     ned2l.dshape <- (6*(EulerM - 1)^2 + pi^2)/(6*Shape^2)  # KK (2003)
     ned2l.dshapescale <- (EulerM-1) / Scale
@@ -1217,7 +1284,7 @@ if (FALSE)
     wz
   }), list( .eshape = eshape, .nrfs = nrfs,
             .scale.12 = scale.12, .scale.TF = scale.TF, .lss = lss ))))
-}
+}  # weibullR
 
 
 
@@ -1312,7 +1379,7 @@ function (time, time2, event, type = c("right", "left", "interval",
   attr(ss, "type") <- type
   class(ss) <- "SurvS4"
   ss
-}
+}  # SurvS4
 
 
 
@@ -1351,7 +1418,7 @@ as.character.SurvS4 <- function (x, ...) {
         ", ", format(x[, 2]), sep = ""), format(x[, 1]))
     ifelse(is.na(stat), as.character(NA), paste(temp2, temp, sep = ""))
   }
-}
+}  # as.character.SurvS4
 
 
 
@@ -1369,7 +1436,8 @@ as.character.SurvS4 <- function (x, ...) {
         class(x) <- NULL
         NextMethod("[")
     }
-}
+}  # "[.SurvS4"
+
 
 
 is.na.SurvS4 <- function(x) {
@@ -1382,6 +1450,8 @@ is.na.SurvS4 <- function(x) {
 
 
 
+
+
 show.SurvS4 <- function (object)
   print.default(as.character.SurvS4(object), quote = FALSE)
 
@@ -1404,7 +1474,8 @@ pgamma.deriv.unscaled <- function(q, shape) {
 
 
 
-  gam0 <- exp(lgamma(shape) + pgamma(q = q, shape = shape, log.p = TRUE))
+  gam0 <- exp(lgamma(shape) + pgamma(q = q, shape = shape,
+                                     log.p = TRUE))
 
   I.sq <- pgamma(q = q, shape = shape)
 
@@ -1423,7 +1494,7 @@ pgamma.deriv.unscaled <- function(q, shape) {
   cbind("0" = gam0,
         "1" = gam1,
         "2" = gam2)
-}
+}  # pgamma.deriv.unscaled
 
 
 
@@ -1432,7 +1503,7 @@ pgamma.deriv.unscaled <- function(q, shape) {
 
  truncweibull <-
   function(lower.limit = 1e-5,
-           lAlpha = "loge", lBetaa = "loge",
+           lAlpha = "loglink", lBetaa = "loglink",
            iAlpha = NULL,   iBetaa = NULL,
            nrfs = 1,
            probs.y = c(0.2, 0.5, 0.8),
@@ -1546,8 +1617,8 @@ pgamma.deriv.unscaled <- function(q, shape) {
            "don't use SurvS4()")
 
 
-    mynames1 <- param.names("Alpha", ncoly)
-    mynames2 <- param.names("Betaa", ncoly)
+    mynames1 <- param.names("Alpha", ncoly, skip1 = TRUE)
+    mynames2 <- param.names("Betaa", ncoly, skip1 = TRUE)
     predictors.names <-
         c(namesof(mynames1, .lAlpha , earg = .eAlpha , tag = FALSE),
           namesof(mynames2, .lBetaa , earg = .eBetaa , tag = FALSE))[
@@ -1625,7 +1696,7 @@ pgamma.deriv.unscaled <- function(q, shape) {
       warning("MLE regularity conditions are violated",
               "(Betaa == 2) at the final iteration: ",
               "MLEs exist and are normal and asymptotically ",
-              "efficient but with a slower convergence rate than when ",
+         "efficient but with a slower convergence rate than when ",
               "Betaa > 2")
     }
 
@@ -1750,7 +1821,8 @@ pgamma.deriv.unscaled <- function(q, shape) {
     wz <- arwz2wz(wz, M = M, M1 = M1)
     wz
   }), list( .nrfs = nrfs ))))
-}
+}  # truncweibull
+
 
 
 
