@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2017 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2019 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -171,8 +171,8 @@ EIM.NB.speciald <-
   trigg.term <- if (intercept.only) {
      dnbinom(Y.mat, size = size, mu = mu) %*% trigamma(Y.mat + size)
   } else {
-     rowSums(dnbinom(Y.mat, size = size, mu = mu) *
-             trigamma(Y.mat + size))
+     .rowSums(dnbinom(Y.mat, size = size, mu = mu) * trigamma(Y.mat + size),
+              NROW(Y.mat), NCOL(Y.mat))
   }
   ned2l.dk2 <- trigamma(size) - trigg.term
   if (extra.bit)
@@ -211,17 +211,20 @@ negbinomial.initialize.yj <-
 
 
 
-negbinomial.control <- function(save.weights = TRUE, ...) {
+
+
+
+
+negbinomial.control <- function(save.weights = FALSE, ...) {
+
     list(save.weights = save.weights)
 }
 
 
 
-
-
  negbinomial <-
   function(
-           zero = "size",
+           zero = "size",  # Reinstated
            parallel = FALSE,
            deviance.arg = FALSE,
            type.fitted = c("mean", "quantiles"),
@@ -231,7 +234,7 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
            eps.trig = 1e-7,
            max.support = 4000,
            max.chunk.MB = 30,  # max.memory = Inf is allowed
-           lmu = "loge", lsize = "loge",
+           lmu = "loglink", lsize = "loglink",
            imethod = 1,
            imu = NULL,
            iprobs.y = NULL,  # 0.35,
@@ -292,7 +295,8 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
                "greater than 10, say")
 
 
-    if (is.logical( parallel ) && parallel  && length(zero))
+    if (is.logical( parallel ) && parallel &&
+        !(is.null(zero) || all(is.na(zero)) || zero == ""))
       stop("need to set 'zero = NULL' when parallel = TRUE")
 
 
@@ -308,11 +312,37 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
             "Mean:     mu\n",
             "Variance: mu * (1 + mu / size) for NB-2"),
 
+  charfun = eval(substitute(function(x, eta, extra = NULL,
+                                     varfun = FALSE) {
+    vecTF <- c(TRUE, FALSE)
+    kmat <- eta2theta(eta[, !vecTF, drop = FALSE],
+                      .lsize , earg = .esize )
+    munb <- if ( .lmunb == "nbcanlink") {
+      munb <- kmat / expm1(-eta[, vecTF, drop = FALSE])
+      if (min(munb) <= 0) {
+        munb[munb <= 0] <- median(munb[munb > 0])  # 0.1
+        warning("'munb' has some negative values. ",
+                "Using a temporary fix.")
+      }
+      munb
+    } else {
+      eta2theta(eta[, vecTF, drop = FALSE], .lmunb , earg = .emunb )
+    }
+
+    if (varfun) {
+      munb * (1 + munb / kmat)
+    } else {
+      (kmat / (kmat + munb - munb * exp(x * 1i)))^kmat
+    }
+  }, list( .lmunb = lmunb, .lsize = lsize,
+           .emunb = emunb, .esize = esize ))),
+
   constraints = eval(substitute(expression({
     constraints <- cm.VGAM(matrix(1, M, 1), x = x,
                            bool = .parallel ,
                            constraints = constraints)
 
+
     constraints <- cm.zero.VGAM(constraints, x = x, .zero , M = M,
                                 predictors.names = predictors.names,
                                 M1 = 2)
@@ -323,6 +353,7 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
   infos = eval(substitute(function(...) {
     list(M1    = 2,
          Q1    = 1,
+         charfun = TRUE,
          expected = TRUE,
          imethod = .imethod ,
          mds.min = .mds.min ,
@@ -364,7 +395,7 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
 
 
     assign("CQO.FastAlgorithm",
-          ( .lmunb == "loge") && ( .lsize == "loge"),
+          ( .lmunb == "loglink") && ( .lsize == "loglink"),
            envir = VGAMenv)
 
     if (any(function.name == c("cqo", "cao")) &&
@@ -379,9 +410,9 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
     NOS <- ncoly <- ncol(y)  # Number of species
     M <- M1 * NOS
     predictors.names <-
-     c(namesof(param.names("mu",   NOS),
+     c(namesof(param.names("mu",   NOS, skip1 = TRUE),
                 .lmunb , earg = .emunb , tag = FALSE),
-       namesof(param.names("size", NOS),
+       namesof(param.names("size", NOS, skip1 = TRUE),
                 .lsize , earg = .esize , tag = FALSE))
     predictors.names <- predictors.names[interleave.VGAM(M, M1 = M1)]
 
@@ -439,9 +470,11 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
 
 
       if ( .lmunb == "nbcanlink") {
-        if (any(cond1 <- is.na(etastart[, c(TRUE, FALSE)])) ||
-            any(cond2 <- etastart[, c(TRUE, FALSE)] >= 0))
-          etastart[c(cond1) || c(cond2), c(TRUE, FALSE)] <- -0.1
+        etastart[is.na(etastart)] <- -0.1
+        for (j1 in 1:(M/M1)) {
+          cond1 <- etastart[, j1] >= 0
+          etastart[cond1, j1] <- -0.1
+        }
       }
 
 
@@ -522,18 +555,27 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
       ind2 <- FALSE
 
 
-    save.weights <- control$save.weights <- !all(ind2)
+
+
+    control$save.weights <- save.weights  # Latter assigned in @weights
 
 
     temp0303 <- c(rep_len( .lmunb , NOS),
                   rep_len( .lsize , NOS))
-    names(temp0303) <- c(param.names("mu",   NOS),
-                         param.names("size", NOS))
-    misc$link <- temp0303[interleave.VGAM(M, M1 = M1)] # Already named
+    names(temp0303) <- c(param.names("mu",   NOS, skip1 = TRUE),
+                         param.names("size", NOS, skip1 = TRUE))
+    misc$link <- temp0303[interleave.VGAM(M, M1 = M1)]  # Already named
+
 
     misc$earg <- vector("list", M)
     names(misc$earg) <- names(misc$link)
     for (ii in 1:NOS) {
+
+      if ( .lmunb == "nbcanlink") {
+          newemu$size  <- kmat[, ii]  # At the final iteration
+          newemu$wrt.param <- 1
+      }
+
       misc$earg[[M1*ii-1]] <-
         if ( .lmunb == "nbcanlink") newemu else .emunb 
       misc$earg[[M1*ii  ]] <- .esize
@@ -660,7 +702,7 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
       warning("parameter 'size' has very large values relative ",
               "to 'mu'; ",
               "try fitting a quasi-Poisson ",
-              "model instead.")
+              "model instead (e.g., using glm()).")
     okay1 && overdispersion && okay0
   }, list( .lmunb = lmunb, .emunb = emunb,
            .lsize = lsize, .esize = esize,
@@ -677,17 +719,17 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
     if (control$criterion != "coefficients" &&
         control$half.step)
       warning("Argument 'criterion' should be 'coefficients' or ",
-               "'half.step' should be 'FALSE' when 'deviance.arg = TRUE'")
+        "'half.step' should be 'FALSE' when 'deviance.arg = TRUE'")
 
+     nconstraints <- names(constraints)
 
-    low.index <- ifelse(names(constraints)[1] == "(Intercept)", 2, 1)
-    if (low.index <= length(constraints))
-    for (iii in low.index:length(constraints)) {
+    for (iii in seq_len(length(constraints))) {
       conmat <- constraints[[iii]]
-      if (any(conmat[c(FALSE, TRUE), ] != 0))
-        stop("argument 'deviance.arg' should only be TRUE for NB-2 ",
-             "models; ",
-             "non-zero elements detected for the 'size' parameter." )
+      if (nconstraints[iii] != "(Intercept)" &&
+          any(conmat[c(FALSE, TRUE), ] != 0))
+        stop("argument 'deviance.arg' should only be TRUE for",
+             " NB-2 models; non-zero ",
+             "elements detected for the 'size' parameter." )
     }  # for iii
   }  # (iter == 1 && .deviance.arg )
 
@@ -784,7 +826,7 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
 
 
       eps.trig <- .eps.trig
-      Q.MAXS <- if ( .lsize == "loge")
+      Q.MAXS <- if ( .lsize == "loglink")
         pmax(10, ceiling(kmat[, jay] / sqrt(eps.trig))) else Inf
       Q.maxs <- pmin(Q.maxs, Q.MAXS)
 
@@ -832,6 +874,8 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
 
 
 
+
+
     for (jay in 1:NOS) {
       run.varcov <- 0
       ii.TF <- !ind2[, jay]  # Not assigned above
@@ -856,12 +900,12 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
 
 
 
-    save.weights <- !all(ind2)
-
+    if (any(!ind2))
+      save.weights <- TRUE
 
 
     ned2l.dmunb2 <- 1 / munb - 1 / (munb + kmat)
-    wz[, c(TRUE, FALSE)] <- ned2l.dmunb2 * dmunb.deta1^2
+    wz[, vecTF] <- ned2l.dmunb2 * dmunb.deta1^2
 
 
 
@@ -882,7 +926,9 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
       } else {
         cbind(wz, wzoffdiag)
       }
-    }
+
+
+    }  # if ( .lmunb == "nbcanlink")
 
 
 
@@ -947,7 +993,9 @@ negbinomial.control <- function(save.weights = TRUE, ...) {
 
 
 
-polya.control <- function(save.weights = TRUE, ...) {
+
+polya.control <- function(save.weights = FALSE, ...) {
+
     list(save.weights = save.weights)
 }
 
@@ -962,7 +1010,7 @@ polya.control <- function(save.weights = TRUE, ...) {
            eps.trig = 1e-7,
            max.support = 4000,
            max.chunk.MB = 30,  # max.memory = Inf is allowed
-           lprob = "logit", lsize = "loge",
+           lprob = "logitlink", lsize = "loglink",
            imethod = 1,
            iprob = NULL,
            iprobs.y = NULL,
@@ -1064,10 +1112,10 @@ polya.control <- function(save.weights = TRUE, ...) {
     extra$colnames.y  <- colnames(y)
 
     predictors.names <-
-      c(namesof(param.names("prob", NOS), .lprob , earg = .eprob ,
-                tag = FALSE),
-        namesof(param.names("size", NOS), .lsize , earg = .esize ,
-                tag = FALSE))
+      c(namesof(param.names("prob", NOS, skip1 = TRUE),
+                .lprob , earg = .eprob , tag = FALSE),
+        namesof(param.names("size", NOS, skip1 = TRUE),
+                .lsize , earg = .esize , tag = FALSE))
     predictors.names <- predictors.names[interleave.VGAM(M, M1 = M1)]
 
     if (is.null( .nsimEIM )) {
@@ -1166,10 +1214,12 @@ polya.control <- function(save.weights = TRUE, ...) {
   }, list( .lprob = lprob, .eprob = eprob,
            .lsize = lsize, .esize = esize))),
   last = eval(substitute(expression({
+    control$save.weights <- save.weights  # Latter assigned in @weights
+
     temp0303 <- c(rep_len( .lprob , NOS),
                   rep_len( .lsize , NOS))
-    names(temp0303) <- c(param.names("prob", NOS),
-                         param.names("size", NOS))
+    names(temp0303) <- c(param.names("prob", NOS, skip1 = TRUE),
+                         param.names("size", NOS, skip1 = TRUE))
     temp0303 <- temp0303[interleave.VGAM(M, M1 = M1)]
     misc$link <- temp0303  # Already named
 
@@ -1197,7 +1247,7 @@ polya.control <- function(save.weights = TRUE, ...) {
     pmat  <- eta2theta(eta[, c(TRUE, FALSE), drop = FALSE],
                        .lprob , earg = .eprob)
     temp300 <-         eta[, c(FALSE, TRUE), drop = FALSE]
-    if ( .lsize == "loge") {
+    if ( .lsize == "loglink") {
       bigval <- 68
       temp300[temp300 >  bigval] <-  bigval
       temp300[temp300 < -bigval] <- -bigval
@@ -1243,7 +1293,7 @@ polya.control <- function(save.weights = TRUE, ...) {
     okay1 <- all(is.finite(munb)) && all(0 < munb) &&
              all(is.finite(size)) && all(0 < size) &&
              all(is.finite(pmat)) && all(0 < pmat & pmat < 1)
-    overdispersion <- if (okay1) all(munb / size > smallval) else FALSE
+    overdispersion <- if (okay1) all(smallval < munb / size) else FALSE
     if (!overdispersion)
       warning("parameter 'size' has very large values; ",
               "try fitting a quasi-Poisson ",
@@ -1261,7 +1311,7 @@ polya.control <- function(save.weights = TRUE, ...) {
     pmat  <- eta2theta(eta[, c(TRUE, FALSE), drop = FALSE],
                        .lprob , earg = .eprob )
     temp3 <-           eta[, c(FALSE, TRUE), drop = FALSE]
-    if ( .lsize == "loge") {
+    if ( .lsize == "loglink") {
       bigval <- 68
       temp3[temp3 >  bigval] <-  bigval  # pmin() collapses matrices
       temp3[temp3 < -bigval] <- -bigval
@@ -1364,7 +1414,9 @@ polya.control <- function(save.weights = TRUE, ...) {
     wz[,     M1*(1:NOS)    ] <- wz[,      M1 * (1:NOS)] * dkayy.deta^2
 
 
-    save.weights <- !all(ind2)
+    if (any(!ind2))
+      save.weights <- TRUE
+
 
 
     ned2l.dprob2 <- kmat / ((1 - pmat) * pmat^2)
@@ -1397,12 +1449,12 @@ polya.control <- function(save.weights = TRUE, ...) {
 
 
 
-    if ( .lsize == "loge") {
+    if ( .lsize == "loglink") {
       bigval <- 68
       temp300[temp300 >  bigval] <-  bigval
       temp300[temp300 < -bigval] <- -bigval
     } else {
-      stop("can only handle the 'loge' link")
+      stop("can only handle the 'loglink' link")
     }
     kayy <-  eta2theta(temp300, .lsize , earg = .esize)
     devi <- 2 * (y * log(ifelse(y < 1, 1, y) / mu) +
@@ -1448,7 +1500,7 @@ polyaR.control <- function(save.weights = TRUE, ...) {
            eps.trig = 1e-7,
            max.support = 4000,
            max.chunk.MB = 30,  # max.memory = Inf is allowed
-           lsize = "loge", lprob = "logit",
+           lsize = "loglink", lprob = "logitlink",
            imethod = 1,
            iprob = NULL,
            iprobs.y = NULL,
@@ -1551,9 +1603,9 @@ polyaR.control <- function(save.weights = TRUE, ...) {
     extra$colnames.y  <- colnames(y)
 
     predictors.names <-
-      c(namesof(param.names("size", NOS),
+      c(namesof(param.names("size", NOS, skip1 = TRUE),
                 .lsize , earg = .esize , tag = FALSE),
-        namesof(param.names("prob", NOS),
+        namesof(param.names("prob", NOS, skip1 = TRUE),
                 .lprob , earg = .eprob , tag = FALSE))
     predictors.names <- predictors.names[interleave.VGAM(M, M1 = M1)]
 
@@ -1655,8 +1707,8 @@ polyaR.control <- function(save.weights = TRUE, ...) {
   last = eval(substitute(expression({
     temp0303 <- c(rep_len( .lprob , NOS),
                   rep_len( .lsize , NOS))
-    names(temp0303) <- c(param.names("size", NOS),
-                         param.names("prob", NOS))
+    names(temp0303) <- c(param.names("size", NOS, skip1 = TRUE),
+                         param.names("prob", NOS, skip1 = TRUE))
     temp0303 <- temp0303[interleave.VGAM(M, M1 = M1)]
     misc$link <- temp0303  # Already named
 
@@ -1684,7 +1736,7 @@ polyaR.control <- function(save.weights = TRUE, ...) {
     pmat  <- eta2theta(eta[, c(FALSE, TRUE), drop = FALSE],
                        .lprob , earg = .eprob)
     temp300 <-         eta[, c(TRUE, FALSE), drop = FALSE]
-    if ( .lsize == "loge") {
+    if ( .lsize == "loglink") {
       bigval <- 68
       temp300[temp300 >  bigval] <-  bigval
       temp300[temp300 < -bigval] <- -bigval
@@ -1726,7 +1778,7 @@ polyaR.control <- function(save.weights = TRUE, ...) {
     munb <- size * (1 / pmat - 1)
 
     smallval <- .mds.min  # .munb.div.size
-    overdispersion <- all(munb / size > smallval)
+    overdispersion <- all(smallval < munb / size)
     ans <- all(is.finite(munb)) && all(0 < munb) &&
            all(is.finite(size)) && all(0 < size) &&
            all(is.finite(pmat)) && all(0 < pmat & pmat < 1) &&
@@ -1748,7 +1800,7 @@ polyaR.control <- function(save.weights = TRUE, ...) {
     pmat  <- eta2theta(eta[, c(FALSE, TRUE), drop = FALSE],
                        .lprob , earg = .eprob)
     temp3 <-           eta[, c(TRUE, FALSE), drop = FALSE]
-    if ( .lsize == "loge") {
+    if ( .lsize == "loglink") {
       bigval <- 68
       temp3[temp3 >  bigval] <-  bigval  # pmin() collapses matrices
       temp3[temp3 < -bigval] <- -bigval
@@ -1885,12 +1937,12 @@ polyaR.control <- function(save.weights = TRUE, ...) {
 
 
 
-    if ( .lsize == "loge") {
+    if ( .lsize == "loglink") {
       bigval <- 68
       temp300[temp300 >  bigval] <-  bigval
       temp300[temp300 < -bigval] <- -bigval
     } else {
-      stop("can only handle the 'loge' link")
+      stop("can only handle the 'loglink' link")
     }
     kayy <-  eta2theta(temp300, .lsize , earg = .esize)
     devi <- 2 * (y * log(ifelse(y < 1, 1, y) / mu) +
@@ -1917,7 +1969,7 @@ polyaR.control <- function(save.weights = TRUE, ...) {
 
 
  negbinomial.size <- function(size = Inf,
-                              lmu = "loge",
+                              lmu = "loglink",
                               imu = NULL,
                               iprobs.y = 0.35,
                               imethod = 1,
@@ -1995,7 +2047,7 @@ polyaR.control <- function(save.weights = TRUE, ...) {
 
     M <- M1 * ncol(y)
     NOS <- ncoly <- ncol(y)  # Number of species
-    mynames1 <- param.names("mu", NOS)
+    mynames1 <- param.names("mu", NOS, skip1 = TRUE)
     predictors.names <- namesof(mynames1, .lmu , earg = .emu , tag = FALSE)
 
 
@@ -2129,7 +2181,7 @@ polyaR.control <- function(save.weights = TRUE, ...) {
     }
     munb <- eta2theta(eta, .lmu , earg = newemu )
     okay1 <- all(is.finite(munb)) && all(0 < munb) &&
-                                     all(0 < kmat )
+                                     all(0 < kmat)
     okay1
   }, list( .lmu = lmu, .emu = emu, .size = size ))),
 
