@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2018 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2019 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -30,7 +30,7 @@
 
 
   lmean <- "identitylink"
-  lsdev <- "loge"
+  lsdev <- "loglink"
   emean <- list()
   esdev <- list()
 
