@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2017 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2019 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -130,13 +130,19 @@ rrar.Wmat <- function(y, Ranks., MM, ki, plag, aa, uu, n, coeffs) {
 
 
 
-rrar.control <- function(stepsize = 0.5, save.weights = TRUE, ...) {
+
+
+rrar.control <-
+  function(stepsize = 0.5, save.weights = TRUE,
+           summary.HDEtest = FALSE,  # Overwrites the summary() default.
+           ...) {
 
   if (stepsize <= 0 || stepsize > 1) {
     warning("bad value of stepsize; using 0.5 instead")
     stepsize <- 0.5
   }
   list(stepsize = stepsize,
+       summary.HDEtest = summary.HDEtest,
        save.weights = as.logical(save.weights)[1])
 }
 
@@ -172,7 +178,8 @@ rrar.control <- function(stepsize = 0.5, save.weights = TRUE, ...) {
              ki[i] <- max((1:plag)[dsrank == udsrank[i]])
           ki <- c(ki, plag+1)  # For computing a
           Ranks. <- c(Ranks., 0)  # For computing a
-          aa <- sum( (MM-Ranks.[ki[1:uu]]) * (Ranks.[ki[1:uu]]-Ranks.[ki[-1]]) )
+          aa <- sum( (MM-Ranks.[ki[1:uu]]) *
+                     (Ranks.[ki[1:uu]]-Ranks.[ki[-1]]) )
       }
       if (!intercept.only)
         warning("ignoring explanatory variables")
@@ -328,8 +335,8 @@ vglm.garma.control <- function(save.weights = TRUE, ...) {
 
     copy.X.vlm <- TRUE  # x matrix changes at each iteration
 
-    if ( .link == "logit"   || .link == "probit" ||
-         .link == "cloglog" || .link == "cauchit") {
+    if ( .link == "logitlink"   || .link == "probitlink" ||
+         .link == "clogloglink" || .link == "cauchitlink") {
         delete.zero.colns <- TRUE
         eval(process.categorical.data.VGAM)
         mustart <- mustart[tt.index, 2]
@@ -386,18 +393,18 @@ vglm.garma.control <- function(save.weights = TRUE, ...) {
     if (residuals) {
       switch( .link ,
               identitylink   = y - mu,
-              loge       = w * (y / mu - 1),
-              reciprocal = w * (y / mu - 1),
-              inverse    = w * (y / mu - 1),
+              loglink       = w * (y / mu - 1),
+              reciprocallink = w * (y / mu - 1),
+              inverse        = w * (y / mu - 1),
               w * (y / mu - (1-y) / (1 - mu)))
     } else {
       ll.elts <-
       switch( .link ,
               identitylink   = c(w) * (y - mu)^2,
-              loge       = c(w) * (-mu + y * log(mu)),
-              reciprocal = c(w) * (-mu + y * log(mu)),
-              inverse    = c(w) * (-mu + y * log(mu)),
-                           c(w) * (y * log(mu) + (1-y) * log1p(-mu)))
+              loglink        = c(w) * (-mu + y * log(mu)),
+              reciprocallink = c(w) * (-mu + y * log(mu)),
+              inverse        = c(w) * (-mu + y * log(mu)),
+              c(w) * (y * log(mu) + (1-y) * log1p(-mu)))
       if (summation) {
         sum(ll.elts)
       } else {
@@ -426,8 +433,8 @@ vglm.garma.control <- function(save.weights = TRUE, ...) {
   deriv = eval(substitute(expression({
     dl.dmu <- switch( .link ,
                   identitylink = y-mu,
-                  loge       = (y - mu) / mu,
-                  reciprocal = (y - mu) / mu,
+                  loglink       = (y - mu) / mu,
+                  reciprocallink = (y - mu) / mu,
                   inverse    = (y - mu) / mu,
                   (y - mu) / (mu * (1 - mu)))
     dmu.deta <- dtheta.deta(mu, .link , earg = .earg)
@@ -445,9 +452,10 @@ vglm.garma.control <- function(save.weights = TRUE, ...) {
 
 
         x[, 1:p.lm] <- x[, 1:p.lm] -
-                       x.save[tt.index-ii, 1:p.lm] * new.coeffs[ii + p.lm]
-        x[, p.lm+ii] <- temp - x.save[tt.index-ii, 1:p.lm, drop = FALSE] %*%
-                            new.coeffs[1:p.lm]
+                   x.save[tt.index-ii, 1:p.lm] * new.coeffs[ii + p.lm]
+        x[, p.lm+ii] <- temp -
+            x.save[tt.index-ii, 1:p.lm, drop = FALSE] %*%
+            new.coeffs[1:p.lm]
     }
     class(x) <- "matrix" # Added 20020227; 20040226
 
@@ -458,8 +466,8 @@ vglm.garma.control <- function(save.weights = TRUE, ...) {
 
     vary <- switch( .link ,
                    identitylink = 1,
-                   loge       = mu,
-                   reciprocal = mu^2,
+                   loglink       = mu,
+                   reciprocallink = mu^2,
                    inverse    = mu^2,
                    mu * (1 - mu))
     c(w) * dtheta.deta(mu, link = .link , earg = .earg )^2 / vary
@@ -593,9 +601,9 @@ AR1.control <- function(epsilon  = 1e-6,
 
  AR1 <-
   function(ldrift = "identitylink",
-           lsd  = "loge",
-           lvar = "loge",
-           lrho = "rhobit",
+           lsd  = "loglink",
+           lvar = "loglink",
+           lrho = "rhobitlink",
            idrift  = NULL,
            isd  = NULL,
            ivar = NULL,
@@ -732,11 +740,11 @@ AR1.control <- function(epsilon  = 1e-6,
        n <- nrow(y)
        M <- M1*NOS
 
-       var.names <- param.names("var", NOS)
-       sdv.names <- param.names("sd",  NOS)
+       var.names <- param.names("var", NOS, skip1 = TRUE)
+       sdv.names <- param.names("sd",  NOS, skip1 = TRUE)
        smn.names <- if ( .nodrift ) NULL else
-         param.names("drift",   NOS)
-       rho.names <- param.names("rho", NOS)
+         param.names("drift",   NOS, skip1 = TRUE)
+       rho.names <- param.names("rho", NOS, skip1 = TRUE)
 
        mynames1 <- smn.names
        mynames2 <- if ( .var.arg ) var.names else sdv.names
@@ -1111,9 +1119,9 @@ AR1.control <- function(epsilon  = 1e-6,
              matAux2[, kk] <- rowSums(pf.mat[, kk , ])
            }
            matAux <- cbind(matAux1, if (.poratM ) matAux2 else NULL)
-           colnames(matAux) <- c(paste("ApproxEIM.R",1:NOS, sep = ""),
+           colnames(matAux) <- c(param.names("ApproxEIM.R", NOS),
                                  if (!(.poratM )) NULL else
-                                   paste("ExactEIM.R",1:NOS, sep = ""))
+                                 param.names("ExactEIM.R", NOS))
 
            matAux <- matAux[, interleave.VGAM( (1 + .poratM) * NOS,
                                                M1 = 1 + .poratM)]
