@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2013 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2019 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -8,39 +8,41 @@
 
 
 
-rrvglm <- function(formula,
-                 family, data=list(), 
-                 weights = NULL, subset = NULL, na.action=na.fail,
-                 etastart = NULL, mustart = NULL, coefstart = NULL,
-                 control=rrvglm.control(...), 
-                 offset = NULL, 
-                 method="rrvglm.fit",
-                 model = FALSE, x.arg = TRUE, y.arg = TRUE,
-                 contrasts = NULL, 
-                 constraints = NULL,
-                 extra = NULL, 
-                 qr.arg = FALSE, smart = TRUE, ...)
-{
+rrvglm <-
+  function(formula,
+           family = stop("argument 'family' needs to be assigned"),
+           data = list(),
+           weights = NULL, subset = NULL, na.action = na.fail,
+           etastart = NULL, mustart = NULL, coefstart = NULL,
+           control = rrvglm.control(...),
+           offset = NULL,
+           method="rrvglm.fit",
+           model = FALSE, x.arg = TRUE, y.arg = TRUE,
+           contrasts = NULL,
+           constraints = NULL,
+           extra = NULL,
+           qr.arg = FALSE, smart = TRUE, ...) {
     dataname <- as.character(substitute(data))  # "list" if no data=
     function.name <- "rrvglm"
 
     ocall <- match.call()
 
-    if (smart) 
+    if (smart)
         setup.smart("write")
 
     mt <- terms(formula, data = data)
-    if (missing(data)) 
+    if (missing(data))
         data <- environment(formula)
 
     mf <- match.call(expand.dots = FALSE)
-    mf$family <- mf$method <- mf$model <- mf$x.arg <- mf$y.arg <- mf$control <-
-        mf$contrasts <- mf$constraints <- mf$extra <- mf$qr.arg <- NULL
+    mf$family <- mf$method <- mf$model <- mf$x.arg <- mf$y.arg <-
+    mf$control <- mf$contrasts <- mf$constraints <- mf$extra <-
+    mf$qr.arg <- NULL
     mf$coefstart <- mf$etastart <- mf$... <- NULL
     mf$smart <- NULL
-    mf$drop.unused.levels <- TRUE 
+    mf$drop.unused.levels <- TRUE
     mf[[1]] <- as.name("model.frame")
-    mf <- eval(mf, parent.frame()) 
+    mf <- eval(mf, parent.frame())
     if (method == "model.frame")
         return(mf)
     na.act <- attr(mf, "na.action")
@@ -60,12 +62,12 @@ rrvglm <- function(formula,
 
 
     offset <- model.offset(mf)
-    if (is.null(offset)) 
-        offset <- 0 # yyy ???
+    if (is.null(offset))
+      offset <- 0  # yyy ???
     w <- model.weights(mf)
-    if (!length(w))
-        w <- rep(1, nrow(mf))
-    else if (ncol(as.matrix(w))==1 && any(w < 0))
+    if (!length(w)) {
+      w <- rep_len(1, nrow(mf))
+    } else if (NCOL(w) == 1 && any(w < 0))
         stop("negative weights not allowed")
 
     if (is.character(family))
@@ -81,7 +83,6 @@ rrvglm <- function(formula,
     if (!is.null(family@first))
         eval(family@first)
 
-    # 10/12/04: testing for an empty (function) slot not elegant:
     if (control$Quadratic && control$FastAlgorithm &&
        length(as.list(family@deviance)) <= 1)
         stop("The fast algorithm requires the family ",
@@ -90,54 +91,56 @@ rrvglm <- function(formula,
 
     rrvglm.fitter <- get(method)
 
-    fit <- rrvglm.fitter(x=x, y=y, w=w, offset=offset, 
-                       etastart=etastart, mustart=mustart, coefstart=coefstart,
-                       family=family, 
-                       control=control,
-                       constraints=constraints,
-                       criterion=control$criterion,
-                       extra=extra,
-                       qr.arg = qr.arg,
-                       Terms=mt, function.name=function.name, ...)
+    fit <- rrvglm.fitter(x = x, y = y, w = w, offset = offset,
+                        etastart = etastart, mustart = mustart,
+                        coefstart = coefstart,
+                        family = family,
+                        control = control,
+                        constraints = constraints,
+                        criterion = control$criterion,
+                        extra = extra,
+                        qr.arg  =  qr.arg,
+                        Terms = mt, function.name = function.name, ...)
 
     if (control$Bestof > 1) {
-        deviance.Bestof = rep(fit$crit.list$deviance, len= control$Bestof)
-        for(tries in 2:control$Bestof) {
-             if (control$trace && (control$Bestof>1))
-             cat(paste("\n========================= Fitting model", tries,
-                         "=========================\n\n"))
-             it <- rrvglm.fitter(x=x, y=y, w=w, offset=offset, 
-                       etastart=etastart, mustart=mustart, coefstart=coefstart,
-                       family=family, 
-                       control=control,
-                       constraints=constraints,
-                       criterion=control$criterion,
-                       extra=extra,
-                       qr.arg = qr.arg,
-                       Terms=mt, function.name=function.name, ...)
-            deviance.Bestof[tries] = it$crit.list$deviance
-            if (min(deviance.Bestof[1:(tries-1)]) > deviance.Bestof[tries])
-                fit = it
-        }
-        fit$misc$deviance.Bestof = deviance.Bestof
+      deviance.Bestof <- rep_len(fit$crit.list$deviance, control$Bestof)
+      for (tries in 2:control$Bestof) {
+         if (control$trace && (control$Bestof>1))
+           cat(paste("\n========================= Fitting model", tries,
+                       "=========================\n\n"))
+         it <- rrvglm.fitter(x = x, y = y, w = w, offset = offset,
+                   etastart = etastart, mustart = mustart,
+                   coefstart = coefstart,
+                   family = family,
+                   control = control,
+                   constraints = constraints,
+                   criterion = control$criterion,
+                   extra = extra,
+                   qr.arg = qr.arg,
+                   Terms = mt, function.name = function.name, ...)
+        deviance.Bestof[tries] <- it$crit.list$deviance
+        if (min(deviance.Bestof[1:(tries-1)]) > deviance.Bestof[tries])
+          fit <- it
+      }
+      fit$misc$deviance.Bestof = deviance.Bestof
     }
 
     fit$misc$dataname <- dataname
 
     if (smart) {
-        fit$smart.prediction <- get.smart.prediction()
-        wrapup.smart()
+      fit$smart.prediction <- get.smart.prediction()
+      wrapup.smart()
     }
 
     answer <-
-    new(if(control$Quadratic) "qrrvglm" else "rrvglm",
+    new(if (control$Quadratic) "qrrvglm" else "rrvglm",
       "assign"       = attr(x, "assign"),
       "call"         = ocall,
       "coefficients" = fit$coefficients,
       "constraints"  = fit$constraints,
       "criterion"    = fit$crit.list,
       "df.residual"  = fit$df.residual,
-      "df.total"     = fit$df.total, 
+      "df.total"     = fit$df.total,
       "dispersion"   = 1,
       "effects"      = fit$effects,
       "family"       = fit$family,
@@ -146,9 +149,9 @@ rrvglm <- function(formula,
       "R"            = fit$R,
       "rank"         = fit$rank,
       "residuals"    = as.matrix(fit$residuals),
-      "rss"          = fit$rss,
+      "ResSS"       = fit$ResSS,
       "smart.prediction" = as.list(fit$smart.prediction),
-      "terms"        = list(terms=mt))
+      "terms"        = list(terms = mt))
 
     if (!smart) answer@smart.prediction <- list(smart.arg = FALSE)
 
@@ -180,10 +183,10 @@ rrvglm <- function(formula,
             warning("\"extra\" is not a list, therefore placing \"extra\" into a list")
             list(fit$extra)
         }
-    } else list() # R-1.5.0
+    } else list()  # R-1.5.0
 
     slot(answer, "iter") = fit$iter
-    fit$predictors = as.matrix(fit$predictors)  # Must be a matrix 
+    fit$predictors = as.matrix(fit$predictors)  # Must be a matrix
     dimnames(fit$predictors) = list(dimnames(fit$predictors)[[1]],
                                     fit$misc$predictors.names)
     slot(answer, "predictors") = fit$predictors
